---
feature_story: FS_18_64_57_18
feature_title: function with indefinite input data envelopes like varargs
feature_status: TEST
---

Some functions need to accept arbitrary number of `data_envelope`-s
all of which are from search results (normally, search has to single out one `data_envelope`).
The feature is similar to function varargs (when the last search allows any number of results).
